INSERT INTO distribution(name) VALUES ('Debian');

INSERT INTO format(name) VALUES ('deb');

INSERT INTO status(name) VALUES
	('Waiting'),
	('Blocked'),
	('Cancelled'),
	('Building'),
	('Failed'),
	('Uploaded'),
	('Done');
